@@ -19,11 +19,13 @@ import numpy as np
 import pandas as pd
 import time
 from langchain_core.language_models.chat_models import BaseChatModel
+from langchain_core.messages import BaseMessage
 import rich
 from rich import print as rprint
 
 from uqlm.judges.judge import LLMJudge
-from uqlm.scorers.baseclass.uncertainty import UncertaintyQuantifier, UQResult
+from uqlm.scorers.baseclass.uncertainty import UncertaintyQuantifier
+from uqlm.utils.results import UQResult
 from uqlm.scorers.panel import LLMPanel
 from uqlm.scorers.black_box import BlackBoxUQ
 from uqlm.scorers.white_box import WhiteBoxUQ
@@ -38,7 +40,7 @@ class UQEnsemble(UncertaintyQuantifier):
         scorers: Optional[List[Union[str, BaseChatModel, LLMJudge]]] = None,
         device: Any = None,
         postprocessor: Any = None,
-        system_prompt: str = "You are a helpful assistant.",
+        system_prompt: Optional[str] = None,
         max_calls_per_min: Optional[int] = None,
         use_n_param: bool = False,
         thresh: float = 0.5,
@@ -46,6 +48,7 @@ class UQEnsemble(UncertaintyQuantifier):
         nli_model_name: str = "microsoft/deberta-large-mnli",
         use_best: bool = True,
         sampling_temperature: float = 1.0,
+        scoring_templates: Optional[List[str]] = None,
         max_length: int = 2000,
         verbose: bool = False,
         return_responses: str = "all",
@@ -79,8 +82,9 @@ class UQEnsemble(UncertaintyQuantifier):
         sampling_temperature : float, default=1.0
             The 'temperature' parameter for llm model to generate sampled LLM responses. Must be greater than 0.
 
-        system_prompt : str or None, default="You are a helpful assistant."
-            Optional argument for user to provide custom system prompt
+        system_prompt : str, default=None
+            Optional argument for user to provide custom system prompt. If prompts are list of strings and system_prompt is None,
+            defaults to "You are a helpful assistant."
 
         max_calls_per_min : int, default=None
             Specifies how many api calls to make per minute to avoid a rate limit error. By default, no
@@ -100,6 +104,13 @@ class UQEnsemble(UncertaintyQuantifier):
             Specifies which NLI model to use. Must be acceptable input to AutoTokenizer.from_pretrained() and
             AutoModelForSequenceClassification.from_pretrained()
 
+        scoring_templates : List[str], default=None
+             Specifies which off-the-shelf template to use for each judge. Four off-the-shelf templates offered:
+             incorrect/uncertain/correct (0/0.5/1), incorrect/correct (0/1), continuous score (0 to 1), and likert scale score ( 1-5 scale, normalized to 0/0.25/0.5/0.75/1).
+             These templates are respectively specified as 'true_false_uncertain', 'true_false', 'continuous', and 'likert'
+             If specified, must be of equal length to `judges` list. Defaults to 'true_false_uncertain' template
+             used by Chen and Mueller (2023) :footcite:`chen2023quantifyinguncertaintyanswerslanguage` for each judge.
+
         max_length : int, default=2000
             Specifies the maximum allowed string length. Responses longer than this value will be truncated to
             avoid OutOfMemoryError
@@ -120,18 +131,21 @@ class UQEnsemble(UncertaintyQuantifier):
         self.use_best = use_best
         self.max_length = max_length
         self.return_responses = return_responses
+        self.scoring_templates = scoring_templates
         self.tuner = Tuner()
         self._validate_components(scorers)
         self._validate_weights()
 
-    async def generate_and_score(self, prompts: List[str], num_responses: int = 5, show_progress_bars: Optional[bool] = True, _existing_progress_bar: Optional[rich.progress.Progress] = None) -> UQResult:
+    async def generate_and_score(self, prompts: List[Union[str, List[BaseMessage]]], num_responses: int = 5, show_progress_bars: Optional[bool] = True, _existing_progress_bar: Optional[rich.progress.Progress] = None) -> UQResult:
         """
         Generate LLM responses from provided prompts and compute confidence scores.
 
         Parameters
         ----------
-        prompts : list of str
-            A list of input prompts for the model.
+        prompts : List[Union[str, List[BaseMessage]]]
+            List of prompts from which LLM responses will be generated. Prompts in list may be strings or lists of BaseMessage. If providing
+            input type List[List[BaseMessage]], refer to https://python.langchain.com/docs/concepts/messages/#langchain-messages for support.
+            Must be list of strings if including LLM judges in ensemble.
 
         num_responses : int, default=5
             The number of sampled responses used to compute consistency.
@@ -152,12 +166,15 @@ class UQEnsemble(UncertaintyQuantifier):
             """
             self.llm.logprobs = True
 
+        if self.judges:
+            if not all(isinstance(item, str) for item in prompts):
+                raise ValueError("prompts must be list of strings when using LLM judges with UQEnsemble")
         self._construct_progress_bar(show_progress_bars, _existing_progress_bar=_existing_progress_bar)
         self._display_generation_header(show_progress_bars)
 
         responses = await self.generate_original_responses(prompts, progress_bar=self.progress_bar)
         if self.black_box_components:
-            sampled_responses = await self.generate_candidate_responses(prompts, progress_bar=self.progress_bar)
+            sampled_responses = await self.generate_candidate_responses(prompts, num_responses=self.num_responses, progress_bar=self.progress_bar)
         else:
             sampled_responses = None
 
@@ -463,7 +480,10 @@ class UQEnsemble(UncertaintyQuantifier):
 
     def _construct_result(self) -> Any:
         """Constructs UQResult from dictionary"""
-        data = {"prompts": self.prompts, "responses": self.responses, "sampled_responses": self.sampled_responses if self.sampled_responses else [None] * len(self.responses)}
+        if self.black_box_components:
+            data = self._construct_black_box_return_data()
+        else:
+            data = {"prompts": self.prompts, "responses": self.responses, "sampled_responses": self.sampled_responses if self.sampled_responses else [None] * len(self.responses)}
         data["ensemble_scores"] = self._compute_ensemble_scores(score_dict=self.component_scores, weights=self.weights)
         data.update(self.component_scores)
         result = {"data": data, "metadata": {"temperature": None if not self.llm else self.llm.temperature, "sampling_temperature": None if not self.sampling_temperature else self.sampling_temperature, "num_responses": self.num_responses, "thresh": self.thresh, "weights": self.weights, "logprobs": self.logprobs}}
@@ -514,7 +534,7 @@ class UQEnsemble(UncertaintyQuantifier):
         if self.white_box_components:
             self.white_box_object = WhiteBoxUQ()
         if self.judges:
-            self.judges_object = LLMPanel(judges=self.judges, max_calls_per_min=self.max_calls_per_min)
+            self.judges_object = LLMPanel(judges=self.judges, max_calls_per_min=self.max_calls_per_min, scoring_templates=self.scoring_templates)
         self.components = components
 
     def _validate_weights(self) -> None:
