@@ -13,12 +13,14 @@
 # limitations under the License.
 
 
-from uqlm.utils.plots import plot_model_accuracies
+from uqlm.utils.plots import plot_model_accuracies, plot_filtered_accuracy, plot_ranked_auc
 from uqlm.utils.dataloader import load_dataset, load_example_dataset
 from uqlm.utils.postprocessors import math_postprocessor
 from uqlm.utils.response_generator import ResponseGenerator
+from uqlm.utils.results import UQResult
 from uqlm.utils.tuner import Tuner
 from uqlm.utils.llm_config import save_llm_config, load_llm_config
 from uqlm.utils.display import ConditionalBarColumn, ConditionalTimeElapsedColumn, ConditionalTextColumn, ConditionalSpinnerColumn
+from uqlm.utils.warn import beta_warning
 
-__all__ = ["plot_model_accuracies", "load_example_dataset", "load_dataset", "load_example_dataset", "math_postprocessor", "ResponseGenerator", "Tuner", "save_llm_config", "load_llm_config", "ConditionalBarColumn", "ConditionalTimeElapsedColumn", "ConditionalTextColumn", "ConditionalSpinnerColumn"]
+__all__ = ["plot_model_accuracies", "plot_filtered_accuracy", "plot_ranked_auc", "load_example_dataset", "load_dataset", "load_example_dataset", "math_postprocessor", "ResponseGenerator", "UQResult", "Tuner", "save_llm_config", "load_llm_config", "ConditionalBarColumn", "ConditionalTimeElapsedColumn", "ConditionalTextColumn", "ConditionalSpinnerColumn", "beta_warning"]
